package cz.muni.fi.pa165.entity;

import cz.muni.fi.pa165.entity.interfaces.Viewable;
import cz.muni.fi.pa165.enums.CountryEnum;
import lombok.Getter;
import lombok.Setter;

import javax.persistence.*;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.Set;

/**
 * @author mvalko
 */

@Setter
@Getter
@Entity
public class TeamEntity extends BaseEntity implements Viewable {

    @Column(nullable = false, unique = true)
    private String name;
    private CountryEnum country;

    @OneToMany(mappedBy = "team")
    private Set<PlayerEntity> playerList = new HashSet<>();

    @OneToMany(mappedBy = "team")
    private Set<TeamCoachEntity> coachList = new HashSet<>();

    @ManyToMany(mappedBy = "teamsEnrolled")
    private Set<TournamentEntity> completedTournaments = new HashSet<>();

    @ManyToMany(mappedBy = "teamsSigned")
    private Set<TournamentEntity> plannedTournaments = new HashSet<>();


    public TeamEntity(){

    }

    public TeamEntity(String name, Set<TeamCoachEntity> coaches){
        this.name = name;
        this.coachList = coaches;
    }

    @Override
    public ArrayList<String> getInformation() {
        return null;
    }

    @Override
    public String getConcreteInformation() {
        return null;
    }

    /**
     * Adds player who recently joined the team to the playerList.
     * @param newPlayer PlayerEntity that is to be added to the playerList.
     */
    public void addPlayerToTheTeam(PlayerEntity newPlayer){
        this.playerList.add(newPlayer);
    }

    /**
     * Removes player who left the team from the playerList.
     * @param oldPlayer PlayerEntity that is to be removed from the playerList.
     */
    public void removePlayerFromTheTeam(PlayerEntity oldPlayer) {
        this.playerList.remove(oldPlayer);
    }

    /**
     * Adds coach who recently joined the team to the coachList.
     * @param newCoach TeamCoachEntity that is to be added to the coachList.
     */
    public void addCoachToTheTeam(TeamCoachEntity newCoach) {
        this.coachList.add(newCoach);
    }

    /**
     * Removes coach who left the team from the coachList.
     * @param oldCoach TeamCoachEntity that is to be removed from the coachList.
     */
    public void removeCoachFromTheTeam(TeamCoachEntity oldCoach) {
        this.coachList.remove(oldCoach);
    }



}
